==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ar/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "هذا الربع",
	"field-quarter-short-relative+1": "الربع القادم",
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"field-year": "السنة",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء القادم",
	"timeFormat-short": "h:mm a",
	"field-minute": "الدقائق",
	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
	"field-tue-narrow-relative+1": "الثلاثاء القادم",
	"field-thu-short-relative+0": "الخميس الحالي",
	"field-thu-short-relative+1": "الخميس القادم",
	"field-day-relative+0": "اليوم",
	"field-day-relative+1": "غدًا",
	"field-day-relative+2": "بعد الغد",
	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
	"field-year-narrow": "السنة",
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-tue-relative+1": "الثلاثاء القادم",
	"field-second-short": "الثواني",
	"dayPeriods-format-narrow-am": "ص",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-abbr-am": "ص",
	"field-week-relative+0": "هذا الأسبوع",
	"field-month-relative+0": "هذا الشهر",
	"field-week-relative+1": "الأسبوع القادم",
	"field-month-relative+1": "الشهر القادم",
	"field-sun-narrow-relative+0": "الأحد الحالي",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "الاثنين الحالي",
	"field-sun-narrow-relative+1": "الأحد القادم",
	"field-mon-short-relative+1": "الإثنين القادم",
	"field-second-relative+0": "الآن",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"eraNames": [
		"ه.ش"
	],
	"dayPeriods-standAlone-abbr-pm": "م",
	"field-month-short": "الشهر",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "يوم",
	"field-year-relative+-1": "السنة الماضية",
	"dayPeriods-format-wide-am": "ص",
	"field-sat-short-relative+-1": "السبت الماضي",
	"field-hour-relative+0": "الساعة الحالية",
	"dateFormatItem-yyyyMEd": "E، d/M/y G",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"field-sat-narrow-relative+-1": "السبت الماضي",
	"field-second": "الثواني",
	"days-standAlone-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"dayPeriods-standAlone-wide-pm": "مساءً",
	"dateFormat-long": "d MMMM، y G",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"field-quarter": "ربع السنة",
	"field-week-short": "الأسبوع",
	"quarters-standAlone-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"days-format-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"field-tue-short-relative+0": "الثلاثاء الحالي",
	"field-tue-short-relative+1": "الثلاثاء القادم",
	"field-mon-relative+-1": "الاثنين الماضي",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "الشهر",
	"field-day-narrow": "يوم",
	"field-minute-short": "الدقائق",
	"field-dayperiod": "ص/م",
	"field-sat-short-relative+0": "السبت الحالي",
	"field-sat-short-relative+1": "السبت القادم",
	"dayPeriods-format-narrow-pm": "م",
	"dateFormat-medium": "dd/MM/y G",
	"dateFormatItem-yyyyMMMM": "MMMM، y G",
	"eraAbbr": [
		"ه.ش"
	],
	"quarters-standAlone-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dayPeriods-format-abbr-pm": "م",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "الثواني",
	"field-mon-relative+0": "الاثنين الحالي",
	"field-mon-relative+1": "الاثنين القادم",
	"field-year-short": "السنة",
	"months-format-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"field-quarter-relative+-1": "الربع الأخير",
	"dateFormatItem-yyyyMMMd": "d MMM، y G",
	"dayPeriods-standAlone-narrow-am": "ص",
	"days-format-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"quarters-format-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"dayPeriods-format-wide-pm": "م",
	"field-sat-relative+-1": "السبت الماضي",
	"dateFormatItem-Md": "d/M",
	"field-hour": "الساعات",
	"months-format-wide": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"dateFormat-full": "EEEE، d MMMM، y G",
	"field-month-relative+-1": "الشهر الماضي",
	"field-quarter-short": "ربع السنة",
	"field-sat-narrow-relative+0": "السبت الحالي",
	"field-fri-relative+0": "الجمعة الحالي",
	"field-sat-narrow-relative+1": "السبت القادم",
	"field-fri-relative+1": "الجمعة القادم",
	"field-sun-short-relative+0": "الأحد الحالي",
	"field-sun-short-relative+1": "الأحد القادم",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-quarter-short-relative+-1": "الربع الأخير",
	"months-format-abbr": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"field-quarter-relative+0": "هذا الربع",
	"field-minute-relative+0": "هذه الدقيقة",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "الربع القادم",
	"field-wed-short-relative+-1": "الأربعاء الماضي",
	"dateFormat-short": "d/M/y GGGGG",
	"field-thu-short-relative+-1": "الخميس الماضي",
	"days-standAlone-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
	"field-mon-narrow-relative+-1": "الإثنين الماضي",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "الخميس الماضي",
	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "م",
	"field-wed-short-relative+0": "الأربعاء الحالي",
	"months-standAlone-wide": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"field-wed-short-relative+1": "الأربعاء القادم",
	"field-sun-relative+-1": "الأحد الماضي",
	"days-standAlone-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-weekday": "اليوم",
	"field-quarter-narrow-relative+0": "هذا الربع",
	"field-sat-relative+0": "السبت الحالي",
	"field-quarter-narrow-relative+1": "الربع القادم",
	"field-sat-relative+1": "السبت القادم",
	"months-standAlone-abbr": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"timeFormat-full": "h:mm:ss a zzzz",
	"dateFormatItem-MEd": "E، d/M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "الخميس الحالي",
	"field-thu-narrow-relative+1": "الخميس القادم",
	"field-sun-narrow-relative+-1": "الأحد الماضي",
	"field-mon-short-relative+-1": "الاثنين الماضي",
	"field-thu-relative+0": "الخميس الحالي",
	"field-thu-relative+1": "الخميس القادم",
	"field-fri-short-relative+-1": "الجمعة الماضي",
	"field-thu-relative+-1": "الخميس الماضي",
	"field-week": "الأسبوع",
	"quarters-standAlone-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"quarters-format-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-Ed": "E، d",
	"field-wed-narrow-relative+0": "الأربعاء الحالي",
	"field-wed-narrow-relative+1": "الأربعاء القادم",
	"field-quarter-narrow-relative+-1": "الربع الأخير",
	"dateFormatItem-yyyyMMM": "MMM، y G",
	"field-fri-short-relative+0": "الجمعة الحالي",
	"field-fri-short-relative+1": "الجمعة القادم",
	"days-standAlone-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "الساعات",
	"quarters-format-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"field-month-narrow": "الشهر",
	"field-hour-narrow": "الساعات",
	"field-fri-narrow-relative+-1": "الجمعة الماضي",
	"field-year-relative+0": "السنة الحالية",
	"field-year-relative+1": "السنة القادمة",
	"field-fri-relative+-1": "الجمعة الماضي",
	"eraNarrow": [
		"ه.ش"
	],
	"field-tue-short-relative+-1": "الثلاثاء الماضي",
	"field-minute-narrow": "الدقائق",
	"days-format-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-mon-narrow-relative+0": "الإثنين الحالي",
	"field-mon-narrow-relative+1": "الإثنين القادم",
	"field-zone": "التوقيت",
	"dateFormatItem-MMMEd": "E، d MMM",
	"field-quarter-narrow": "ربع السنة",
	"field-sun-short-relative+-1": "الأحد الماضي",
	"field-day-relative+-1": "أمس",
	"dayPeriods-standAlone-abbr-am": "ص",
	"field-day-relative+-2": "أول أمس",
	"days-format-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-sun-relative+0": "الأحد الحالي",
	"field-sun-relative+1": "الأحد القادم",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "يوم",
	"field-week-narrow": "الأسبوع",
	"field-era": "العصر",
	"field-fri-narrow-relative+0": "الجمعة الحالي",
	"field-fri-narrow-relative+1": "الجمعة القادم",
	"dayPeriods-standAlone-wide-am": "صباحًا"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/ar/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "هذا الربع",
	"field-quarter-short-relative+1": "الربع القادم",
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"field-year": "السنة",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء القادم",
	"timeFormat-short": "h:mm a",
	"field-minute": "الدقائق",
	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
	"field-tue-narrow-relative+1": "الثلاثاء القادم",
	"field-thu-short-relative+0": "الخميس الحالي",
	"field-day-short-relative+-1": "أمس",
	"dateTimeFormat-short": "{1} في {0}",
	"field-thu-short-relative+1": "الخميس القادم",
	"field-day-relative+0": "اليوم",
	"field-day-short-relative+-2": "أول أمس",
	"field-day-relative+1": "غدًا",
	"field-day-relative+2": "بعد الغد",
	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
	"field-year-narrow": "السنة",
	"field-era-short": "العصر",
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-tue-relative+1": "الثلاثاء القادم",
	"field-weekdayOfMonth": "يوم عمل من الشهر",
	"field-second-short": "الثواني",
	"dayPeriods-format-narrow-am": "ص",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "يوم عمل/شهر",
	"dayPeriods-format-abbr-am": "ص",
	"field-week-relative+0": "هذا الأسبوع",
	"field-month-relative+0": "هذا الشهر",
	"field-week-relative+1": "الأسبوع القادم",
	"field-month-relative+1": "الشهر القادم",
	"field-sun-narrow-relative+0": "الأحد الحالي",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "الإثنين الحالي",
	"field-sun-narrow-relative+1": "الأحد القادم",
	"field-mon-short-relative+1": "الإثنين القادم",
	"field-second-relative+0": "الآن",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"eraNames": [
		"ه.ش"
	],
	"field-weekOfMonth": "الأسبوع من الشهر",
	"dayPeriods-standAlone-abbr-pm": "م",
	"field-month-short": "الشهر",
	"dateFormatItem-GyMMMEd": "E، d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "يوم",
	"field-dayOfYear-short": "يوم من سنة",
	"field-year-relative+-1": "السنة الماضية",
	"dayPeriods-format-wide-am": "ص",
	"field-sat-short-relative+-1": "السبت الماضي",
	"field-hour-relative+0": "الساعة الحالية",
	"dateFormatItem-yyyyMEd": "E، d/M/y G",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"dateTimeFormat-medium": "{1} في {0}",
	"field-sat-narrow-relative+-1": "السبت الماضي",
	"field-second": "الثواني",
	"days-standAlone-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"dayPeriods-standAlone-wide-pm": "مساءً",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "ربع السنة",
	"field-week-short": "الأسبوع",
	"field-day-narrow-relative+0": "اليوم",
	"field-day-narrow-relative+1": "غدًا",
	"field-day-narrow-relative+2": "بعد الغد",
	"quarters-standAlone-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"days-format-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"field-tue-short-relative+0": "الثلاثاء الحالي",
	"field-tue-short-relative+1": "الثلاثاء القادم",
	"field-mon-relative+-1": "الإثنين الماضي",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "الشهر",
	"field-day-narrow": "يوم",
	"field-minute-short": "الدقائق",
	"field-dayperiod": "ص/م",
	"field-sat-short-relative+0": "السبت الحالي",
	"field-sat-short-relative+1": "السبت القادم",
	"dayPeriods-format-narrow-pm": "م",
	"dateFormat-medium": "dd/MM/y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"ه.ش"
	],
	"quarters-standAlone-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dayPeriods-format-abbr-pm": "م",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "الثواني",
	"field-mon-relative+0": "الإثنين الحالي",
	"field-mon-relative+1": "الإثنين القادم",
	"field-day-narrow-relative+-1": "أمس",
	"field-year-short": "السنة",
	"field-day-narrow-relative+-2": "أول أمس",
	"months-format-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"field-quarter-relative+-1": "الربع الأخير",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "ص/م",
	"dayPeriods-standAlone-narrow-am": "ص",
	"days-format-short": [
		"أحد",
		"إثنين",
		"ثلاثاء",
		"أربعاء",
		"خميس",
		"جمعة",
		"سبت"
	],
	"quarters-format-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"dayPeriods-format-wide-pm": "م",
	"field-dayOfYear": "يوم من السنة",
	"field-sat-relative+-1": "السبت الماضي",
	"dateTimeFormat-long": "{1} في {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "الساعات",
	"months-format-wide": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"dateFormat-full": "EEEE، d MMMM y G",
	"field-month-relative+-1": "الشهر الماضي",
	"field-quarter-short": "ربع السنة",
	"field-sat-narrow-relative+0": "السبت الحالي",
	"field-fri-relative+0": "الجمعة الحالي",
	"field-sat-narrow-relative+1": "السبت القادم",
	"field-fri-relative+1": "الجمعة القادم",
	"field-sun-short-relative+0": "الأحد الحالي",
	"field-sun-short-relative+1": "الأحد القادم",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-quarter-short-relative+-1": "الربع الأخير",
	"months-format-abbr": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"field-quarter-relative+0": "هذا الربع",
	"field-minute-relative+0": "هذه الدقيقة",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "الربع القادم",
	"field-wed-short-relative+-1": "الأربعاء الماضي",
	"dateFormat-short": "d/M/y GGGGG",
	"field-thu-short-relative+-1": "الخميس الماضي",
	"days-standAlone-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yyyyMMMEd": "E، d MMM y G",
	"field-mon-narrow-relative+-1": "الإثنين الماضي",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "الخميس الماضي",
	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
	"field-weekOfMonth-short": "أسبوع من شهر",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "م",
	"field-wed-short-relative+0": "الأربعاء الحالي",
	"months-standAlone-wide": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"field-wed-short-relative+1": "الأربعاء القادم",
	"field-sun-relative+-1": "الأحد الماضي",
	"days-standAlone-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateTimeFormat-full": "{1} في {0}",
	"field-weekday": "اليوم",
	"field-day-short-relative+0": "اليوم",
	"field-quarter-narrow-relative+0": "هذا الربع",
	"field-sat-relative+0": "السبت الحالي",
	"field-day-short-relative+1": "غدًا",
	"field-quarter-narrow-relative+1": "الربع القادم",
	"field-sat-relative+1": "السبت القادم",
	"field-day-short-relative+2": "بعد الغد",
	"months-standAlone-abbr": [
		"فرفردن",
		"أذربيهشت",
		"خرداد",
		"تار",
		"مرداد",
		"شهرفار",
		"مهر",
		"آيان",
		"آذر",
		"دي",
		"بهمن",
		"اسفندار"
	],
	"field-dayOfYear-narrow": "يوم/سنة",
	"field-weekdayOfMonth-short": "يوم عمل من شهر",
	"timeFormat-full": "h:mm:ss a zzzz",
	"dateFormatItem-MEd": "E، d/M",
	"field-zone-narrow": "توقيت",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "الخميس الحالي",
	"field-thu-narrow-relative+1": "الخميس القادم",
	"field-sun-narrow-relative+-1": "الأحد الماضي",
	"field-mon-short-relative+-1": "الإثنين الماضي",
	"field-thu-relative+0": "الخميس الحالي",
	"field-thu-relative+1": "الخميس القادم",
	"field-fri-short-relative+-1": "الجمعة الماضي",
	"field-thu-relative+-1": "الخميس الماضي",
	"field-week": "الأسبوع",
	"quarters-standAlone-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"quarters-format-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-Ed": "E، d",
	"field-wed-narrow-relative+0": "الأربعاء الحالي",
	"field-wed-narrow-relative+1": "الأربعاء القادم",
	"field-quarter-narrow-relative+-1": "الربع الأخير",
	"field-dayperiod-short": "ص/م",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "الجمعة الحالي",
	"field-fri-short-relative+1": "الجمعة القادم",
	"days-standAlone-short": [
		"أحد",
		"إثنين",
		"ثلاثاء",
		"أربعاء",
		"خميس",
		"جمعة",
		"سبت"
	],
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "الساعات",
	"field-zone-short": "توقيت",
	"quarters-format-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"field-month-narrow": "الشهر",
	"field-hour-narrow": "الساعات",
	"field-fri-narrow-relative+-1": "الجمعة الماضي",
	"field-year-relative+0": "السنة الحالية",
	"field-year-relative+1": "السنة القادمة",
	"field-era-narrow": "العصر",
	"field-fri-relative+-1": "الجمعة الماضي",
	"eraNarrow": [
		"ه.ش"
	],
	"field-tue-short-relative+-1": "الثلاثاء الماضي",
	"field-minute-narrow": "الدقائق",
	"days-format-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-mon-narrow-relative+0": "الإثنين الحالي",
	"field-mon-narrow-relative+1": "الإثنين القادم",
	"field-zone": "التوقيت",
	"dateFormatItem-MMMEd": "E، d MMM",
	"field-weekOfMonth-narrow": "أسبوع/شهر",
	"field-weekday-narrow": "اليوم",
	"field-quarter-narrow": "ربع السنة",
	"field-sun-short-relative+-1": "الأحد الماضي",
	"field-day-relative+-1": "أمس",
	"dayPeriods-standAlone-abbr-am": "ص",
	"field-day-relative+-2": "أول أمس",
	"field-weekday-short": "اليوم",
	"days-format-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-sun-relative+0": "الأحد الحالي",
	"field-sun-relative+1": "الأحد القادم",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "يوم",
	"field-week-narrow": "الأسبوع",
	"field-era": "العصر",
	"field-fri-narrow-relative+0": "الجمعة الحالي",
	"field-fri-narrow-relative+1": "الجمعة القادم",
	"dayPeriods-standAlone-wide-am": "صباحًا"
}
//end v1.x content
);
